@@ -1,6 +1,6 @@
 __all__ = ["Response", "response_from_data"]
 
-from typing import Tuple, Union
+from typing import Optional, Tuple, Union
 
 import attr
 
@@ -28,7 +28,7 @@ _SOURCE_BY_CONTENT_TYPE = {
 }
 
 
-def empty_response(*, status_code: int, response_name: str, config: Config) -> Response:
+def empty_response(*, status_code: int, response_name: str, config: Config, description: Optional[str]) -> Response:
     """Return an untyped response, for when no response type is defined"""
     return Response(
         status_code=status_code,
@@ -38,6 +38,8 @@ def empty_response(*, status_code: int, response_name: str, config: Config) -> R
             nullable=False,
             required=True,
             python_name=PythonIdentifier(value=response_name, prefix=config.field_prefix),
+            description=description,
+            example=None,
         ),
         source="None",
     )
@@ -49,13 +51,21 @@ def response_from_data(
     """Generate a Response from the OpenAPI dictionary representation of it"""
 
     response_name = f"response_{status_code}"
-    if isinstance(data, oai.Reference) or data.content is None:
+    if isinstance(data, oai.Reference):
         return (
-            empty_response(status_code=status_code, response_name=response_name, config=config),
+            empty_response(status_code=status_code, response_name=response_name, config=config, description=None),
             schemas,
         )
 
     content = data.content
+    if not content:
+        return (
+            empty_response(
+                status_code=status_code, response_name=response_name, config=config, description=data.description
+            ),
+            schemas,
+        )
+
     for content_type, media_type in content.items():
         if content_type in _SOURCE_BY_CONTENT_TYPE:
             source = _SOURCE_BY_CONTENT_TYPE[content_type]
@@ -66,7 +76,9 @@ def response_from_data(
 
     if schema_data is None:
         return (
-            empty_response(status_code=status_code, response_name=response_name, config=config),
+            empty_response(
+                status_code=status_code, response_name=response_name, config=config, description=data.description
+            ),
             schemas,
         )
 
