@@ -1,4 +1,4 @@
-from pydantic import Field
+from pydantic import Extra, Field
 
 from ..parameter_location import ParameterLocation
 from .parameter import Parameter
@@ -22,6 +22,7 @@ class Header(Parameter):
     param_in = Field(default=ParameterLocation.HEADER, const=True, alias="in")
 
     class Config:  # pylint: disable=missing-class-docstring
+        extra = Extra.allow
         allow_population_by_field_name = True
         schema_extra = {
             "examples": [
